@@ -165,15 +165,15 @@ std::string Chaine::echappe_shell(const std::string& chaine)
 	std::string r;
 	for(auto &c: chaine)
 	{
-		if(c=='$')
+		switch(c)
 		{
-			r += "\\$";
-			continue;
-		}
-		if(c=='\\')
-		{
-			r += "\\\\";
-			continue;
+			case '$':
+			case '`':
+			case '\\':
+				r += '\\';
+				break;
+			default:
+				break;
 		}
 		r += c;
 	}
