@@ -1252,7 +1252,7 @@ void AttributPaquet::verification(const std::string& type, const size_t position
 
 void OptionPaquet::verification()
 {
-	AttributPaquet::verification("option",_position);
+	AttributPaquet::verification("OPTION",_position);
 }
 
 void ContenuPaquetApplication::verification()
@@ -1275,6 +1275,18 @@ void ContenuPaquetFichier::verification()
 	FichierPaquet::verification(_position);
 }
 
+void ContenuPaquetRepertoire::verification()
+{
+	if(_nom.find_last_of('/')!=std::string::npos)
+	{
+		std::ostringstream oss;
+		oss << "Directory name " << _nom << " is invalid.";
+		Erreur e(oss.str());
+		e.position(_position,_position);
+		throw e;
+	}
+}
+
 void FichierPaquet::verification(const size_t position)
 {
 	_fichier.open(_nom.c_str(),std::ios_base::in);
@@ -1290,7 +1302,7 @@ void FichierPaquet::verification(const size_t position)
 
 void ContenuPaquetConfiguration::verification()
 {
-	AttributPaquet::verification("set",_position);
+	AttributPaquet::verification("SET",_position);
 }
 
 void OptionPaquet::construction(ConfigurationPaquet& configuration)
@@ -1306,17 +1318,23 @@ void OptionPaquet::construction(ConfigurationPaquet& configuration)
 	}
 }
 
-void FichierPaquet::construction(ConfigurationPaquet& configuration, const size_t position)
+std::string FichierPaquet::chemin(ConfigurationPaquet& configuration, const size_t position)
 {
-	_chemin = configuration.lit_chaine("path",0);
-	if((_chemin == "..") or (_chemin.substr(0,3) == "../") or ((_chemin.size()>=3) and (_chemin.substr(_chemin.size()-3,3) == "/..")) or (_chemin.find("/../",0) != std::string::npos))
+	auto chemin = configuration.lit_chaine("path",0);
+	if((chemin == "..") or (chemin.substr(0,3) == "../") or ((chemin.size()>=3) and (chemin.substr(chemin.size()-3,3) == "/..")) or (chemin.find("/../",0) != std::string::npos))
 	{
 		std::ostringstream oss;
-		oss << "File path " << _chemin << " shall not contain references to folder '..'.";
+		oss << "File path " << chemin << " shall not contain references to folder '..'.";
 		Erreur e(oss.str());
 		e.position(position,position);
 		throw e;
 	}
+	return chemin;
+}
+
+void FichierPaquet::construction(ConfigurationPaquet& configuration, const size_t position)
+{
+	_chemin = FichierPaquet::chemin(configuration,position);
 	_fin_de_fichier = configuration.lit_chaine("end_of_file",0);
 	_destination = _chemin + "/$(basename " + _nom + ")";
 	std::string destination = _chemin + "/" ;
@@ -1364,6 +1382,22 @@ void ContenuPaquetFichier::construction(ConfigurationPaquet& configuration)
 	_condition = configuration._condition;
 }
 
+void ContenuPaquetRepertoire::construction(ConfigurationPaquet& configuration)
+{
+	auto chemin = FichierPaquet::chemin(configuration,_position);
+	_mode = configuration.lit_chaine("dir_mode",0);
+	_destination = chemin+'/'+_nom;
+	_condition = configuration._condition;
+	if(not configuration._fichiers.insert(_destination).second)
+	{
+		std::ostringstream oss;
+		oss << "Directory " << _destination << " is already created within the package.";
+		Erreur e(oss.str());
+		e.position(_position,_position);
+		throw e;
+	}
+}
+
 void ContenuPaquetConfiguration::construction(ConfigurationPaquet& configuration)
 {
 	_condition = configuration._condition;
@@ -1480,6 +1514,19 @@ void ContenuPaquetFichier::generation(std::ostream& os)
 	}
 }
 
+void ContenuPaquetRepertoire::generation(std::ostream& os)
+{
+	if(not _condition) return;
+	os	<< "mkdir -p " << _destination << std::endl;
+	if(not _mode.empty())
+	{
+		os	<< "chmod " << _mode << " " << _destination << std::endl
+			<< "if [ $? -ne 0 ] ; then" << std::endl
+			<< "	error \"Unable to set permission mode " << _mode << " on directory " <<_destination << ".\"" << std::endl
+			<< "fi" << std::endl;
+	}
+}
+
 void ContenuPaquetCode::generation(std::ostream& os)
 {
 	if(not _condition) return;
